lidia: A library for computational number theory
================================================

Description
-----------

A library for computational number theory.

Abandoned upstream and has disappeared from the web at TU Darmstadt.

We use as our new upstream a version minimally maintained for the LattE
project.

https://www.math.ucdavis.edu/~latte/software/packages/lidia/current/lidia-2.3.0+latte-patches-2014-10-04.tar.gz

License
-------

lidia is released under the GPL, or so it is claimed. See
https://groups.google.com/forum/#!msg/sage-devel/kTxgPSqrbUM/5Txj3_IKhlQJ
and https://lists.debian.org/debian-legal/2007/07/msg00120.html


Upstream Contact
----------------

Matthias Köppe, UC Davis, CA, USA

